downcast_or_panic

Function downcast_or_panic 

pub fn downcast_or_panic<T>(
    arc_any: Arc<dyn Any + Send + Sync>,
    id: &ArtifactId,
) -> Arc<T>
where T: Any + Send + Sync + 'static,
Downcast a cached Any value to the expected fixture type.

Panics when the cache key maps to a different concrete type.