ArtifactCache

Struct ArtifactCache 

pub struct ArtifactCache { /* private fields */ }
Cache keyed by ArtifactId that stores typed values behind Arc<dyn Any>.

Examples

use std::sync::Arc;
use uselesskey_core_cache::ArtifactCache;
use uselesskey_core_id::{ArtifactId, DerivationVersion};

let cache = ArtifactCache::new();
let id = ArtifactId::new("domain:rsa", "issuer", b"RS256", "good", DerivationVersion::V1);

// Insert once, retrieve many times
cache.insert_if_absent_typed(id.clone(), Arc::new(42u32));
let value = cache.get_typed::<u32>(&id).unwrap();
assert_eq!(*value, 42);

Implementations

Source

impl ArtifactCache

pub fn new() -> Self

Create an empty artifact cache.

pub fn len(&self) -> usize

Number of cache entries.

pub fn is_empty(&self) -> bool

Returns true when there are no entries.

pub fn clear(&self)

Remove all entries from the cache.

pub fn get_typed<T>(&self, id: &ArtifactId) -> Option<Arc<T>>
where T: Any + Send + Sync + 'static,

Retrieve a typed value by id.

Panics if the id exists with a different concrete type.

pub fn insert_if_absent_typed<T>(&self, id: ArtifactId, value: Arc<T>) -> Arc<T>
where T: Any + Send + Sync + 'static,

Insert a typed value if the id is vacant and return the winning cached value.

Panics if an existing value for the same id has a different concrete type.